| yftISO | R Documentation |
Yellowfin tuna (YFT) were captured by purse-seine fishing vessels in the eastern tropical Pacific (ETP) between 16 August 2003 and 16 November 2005. Samples of YFT white muscle tissue were taken for stable isotope analysis.
yftISO
A data frame with 49 observations on the following 10 variables.
IsoSampNoUnique, nonrepeating number for each isotope sample taken from an individual YFT or several YFT aggregated into a composite sample
YrYear in which YFT was captured
MonthMonth YFT was captured
DateDate YFT was captured
LatLatitude coordinates where YFT was captured
LonLongitude coordinates where YFT was captured
SSTSea-surface temperature at location where YFT was captured, measured in degrees C
FL_mmLength, measured as fork length, of YFT in mm
d13CYFT stable isotope ratios relative to the isotope standards
are expressed in the following conventional delta (\delta) notation in parts per thousand (%):
\delta X = ([R_{sample}/R_{standard}]-1)\times 1000
where X is ^{15}N or ^{13}C, and R_{sample} and R_{standard} are the
corresponding ratios of heavy to light isotopes (^{15}N/^{14}N or ^{14}C/^{13}C)
in the sample and standard, respectively.
R_{standard} for \delta^{15}N was atmospheric N_2 and for \delta^{13}C
was the Peedee Belemnite (PDB) limestone formation.
d15NYFT stable isotope ratios relative to the isotope standards are
expressed in the following conventional delta (\delta) notation in parts per thousand (%):
\delta X = ([R_{sample}/R_{standard}]-1)\times 1000
where X is ^{15}N or ^{13}C,
and R_{sample} and R_{standard} are the corresponding ratios of heavy to light isotopes
(^{15}N/^{14}N or ^{14}C/^{13}C)
in the sample and standard, respectively.
R_{standard} for \delta^{15}N was atmospheric N_2 and for \delta^{13}C
was the Peedee Belemnite (PDB) limestone formation.
YFT were sampled onboard the vessels by observers of the Inter-American Tropical Tuna Commission (IATTC, 2004). Fish were randomly subsampled from purse-seine sets immediately after capture, and date, position, and sea-surface temperature (SST) were recorded for each set that yielded samples. Observers measure fork length of the fish, removed samples of white muscle tissue from the dorsal musculature adjacent to the second dorsal fin and stored them at about -20 degrees C until processed further in the lab. Subsamples of white muscle from up to six individual YFT per purse-seine set and size class (<90 and >= 90 cm FL) were combined into one composite sample for stable isotope analysis. Thus, there were 49 composite samples of 225 fish.
Olson RJ, Popp BN, Graham BS, Lopez-Ibarra GA, Galvan-Magana F, Lennert-Cody CE, Bocanegra-Castillo N, Wallsgrove NJ, Gier E, Alatorre-Ramirez V, Balance LT, Fry B (2010) Food web inferences of stable isotope spatial patterns in copepods and yellowfin tuna in the pelagic eastern Pacific Ocean. Prog Oceanogr.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.